const system = require("../../../system");
const ServiceBase = require("../../sve.base");
var settings = require("../../../../config/settings");

class Push360Service {
    constructor() {
        this.pushlogDao = system.getObject("db.common.pushlogDao");
        this.ordercontactsDao = system.getObject("db.dbcorder.ordercontactsDao");
        this.push360Url = settings.push360Url();
        this.auth360Url = settings.auth360Url();
    }

    //推送数据至360
    async pushTmStatus(actionBody) {
        let status = 0;
        if (actionBody.tmStatus == "WAITCOMMIT" || actionBody.tmStatus == "ddj") {
            status = 30;
        }
        if (actionBody.tmStatus == "ROBOT") {
            status = 40;
        }
        let order_id = actionBody.orderNo;
        try {
            var rc = system.getObject("util.execClient");
            let rtn = await rc.exec360GetToken(this.auth360Url)
            if (!rtn || !rtn.stdout) {
                return system.getResult(null, "restPost data is empty");
            }
            let tokenResult = JSON.parse(rtn.stdout);
            let token = tokenResult.access_token;
            let url = this.push360Url + '/api/v1/eshop/GsbOrderUpdate?token=' + token;
            let pushObj = {
                order_id: order_id,
                status: status
            }
            let result = await rc.execPost(pushObj, url);
            var logObj = {
                appid: "",
                appkey: "",
                op: url,
                content: JSON.stringify(actionBody),
                resultInfo: result ? JSON.stringify(result) : ""
            };
            if (!result || !result.stdout) {
                logObj["returnType"] = "0";
                logObj["opTitle"] = "数据推送ali返回失败";
                this.pushlogDao.create(logObj);
                return system.getResultFail(-502, "execPost data is empty");
            } else {
                logObj["returnType"] = "1";
                logObj["opTitle"] = "数据推送ali返回成功";
                this.pushlogDao.create(logObj);
                let stdout = JSON.parse(result.stdout);
                return system.getResultSuccess(stdout);
            }
        } catch (e) {
            this.pushlogDao.create({
                appid: "",
                appkey: "",
                logLevel: "3",
                op: this.push360Url,
                content: JSON.stringify(actionBody),
                resultInfo: JSON.stringify(e.stack),
                returnType: "0",
                opTitle: "数据推送360---异常"
            });
            return system.getResultFail(-500, JSON.stringify(e.stack));
        }
    }

    //发送短信
    async sendMessage(actionBody) {
        try {
            let orderNo = actionBody.orderNo;
            //获取联系人信息
            let item = await this.ordercontactsDao.getItemByOrderNo(actionBody.orderNo);
            let deliveryInfo = actionBody.deliveryInfo;
            if (!item) {
                return system.getResultFail(-1, '获取联系人信息失败');
            }
            let mobile = item.mobile;//联系人手机号
            let tmRegistNum = actionBody.registNumInfo.tmRegistNum;//申请号
            let tmName = deliveryInfo.tm.tmName;//商标名称
            let uploadFileName = actionBody.officialInfo.uploadFileName;//文件名
            let oneNcl = deliveryInfo.nclones[0].code;//大类
            let templateId = 1;
            let failType = {
                "2": "商标注册申请补正通知书",
                "4": "商标注册申请不予受理通知书",
                "5": "商标注册同日申请补送使用证据通知书",
                "7": "商标驳回通知书",
                "8": "商标部分驳回通知书",
                "201": "超时未补正"
            }

            if (failType.hasOwnProperty(actionBody.tmStatus)) {
                templateId = 2;
            }

            var rc = system.getObject("util.execClient");
            let rtn = await rc.exec360GetToken(this.auth360Url)
            if (!rtn || !rtn.stdout) {
                return system.getResult(null, "restPost data is empty");
            }
            let tokenResult = JSON.parse(rtn.stdout);
            let token = tokenResult.access_token;
            let url = this.push360Url + '/api/v1/GsbSendsms';
            let params = tmName + "|" + oneNcl + "|" + tmRegistNum + "|" + uploadFileName;
            let subData = "token=" + token + "&mobile=" + mobile + "&templated=" + templateId + "&replaceContent=" + params;
            let result = await rc.execGet(subData, url);
            var logObj = {
                appid: "",
                appkey: "",
                op: url,
                content: JSON.stringify(actionBody),
                resultInfo: result ? JSON.stringify(result) : ""
            };
            if (!result || !result.stdout) {
                logObj["returnType"] = "0";
                logObj["opTitle"] = "数据推送360返回失败";
                this.pushlogDao.create(logObj);
                return system.getResultFail(-502, "execPost data is empty");
            } else {
                logObj["returnType"] = "1";
                logObj["opTitle"] = "数据推送360返回成功";
                this.pushlogDao.create(logObj);
                let stdout = JSON.parse(result.stdout);
                return system.getResultSuccess(stdout);
            }
        } catch (e) {
            this.pushlogDao.create({
                appid: "",
                appkey: "",
                logLevel: "3",
                op: this.push360Url,
                content: JSON.stringify(actionBody),
                resultInfo: JSON.stringify(e.stack),
                returnType: "0",
                opTitle: "数据推送360短信---异常"
            });
            return system.getResultFail(-500, JSON.stringify(e.stack));
        }
    }
}

module.exports = Push360Service;
